@@ -8,14 +8,14 @@ if sys.version_info[0] < 3:
 else:
     izip = zip
 
-from ctypes import byref, c_void_p
+from ctypes import byref, c_void_p, c_double
 
 from shapely.geos import lgeos
 from shapely.geometry.base import geom_factory, BaseGeometry
-from shapely.geometry import asShape, asLineString, asMultiLineString
+from shapely.geometry import asShape, asLineString, asMultiLineString, Point
 
 __all__ = ['cascaded_union', 'linemerge', 'operator', 'polygonize',
-           'polygonize_full', 'transform', 'unary_union']
+           'polygonize_full', 'transform', 'unary_union', 'triangulate']
 
 
 class CollectionOperator(object):
@@ -155,6 +155,25 @@ cascaded_union = operator.cascaded_union
 unary_union = operator.unary_union
 
 
+def triangulate(geom, tolerance=0.0, edges=False):
+    """Creates the Delaunay triangulation and returns a list of geometries
+
+    The source may be any geometry type. All vertices of the geometry will be
+    used as the points of the triangulation.
+
+    From the GEOS documentation:
+    tolerance is the snapping tolerance used to improve the robustness of
+    the triangulation computation. A tolerance of 0.0 specifies that no
+    snapping will take place.
+
+    If edges is False, a list of Polygons (triangles) will be returned.
+    Otherwise the list of LineString edges is returned.
+
+    """
+    func = lgeos.methods['delaunay_triangulation']
+    gc = geom_factory(func(geom._geom, tolerance, int(edges)))
+    return [g for g in gc.geoms]
+
 class ValidateOp(object):
     def __call__(self, this):
         return lgeos.GEOSisValidReason(this._geom)
@@ -232,3 +251,53 @@ def transform(func, geom):
         return type(geom)([transform(func, part) for part in geom.geoms])
     else:
         raise ValueError('Type %r not recognized' % geom.type)
+
+
+def nearest_points(g1, g2):
+    """Returns the calculated nearest points in the input geometries
+    
+    The points are returned in the same order as the input geometries.
+    """
+    seq = lgeos.methods['nearest_points'](g1._geom, g2._geom)
+    if seq is None:
+        if g1.is_empty:
+            raise ValueError('The first input geometry is empty')
+        else:
+            raise ValueError('The second input geometry is empty')
+    x1 = c_double()
+    y1 = c_double()
+    x2 = c_double()
+    y2 = c_double()
+    lgeos.GEOSCoordSeq_getX(seq, 0, byref(x1))
+    lgeos.GEOSCoordSeq_getY(seq, 0, byref(y1))
+    lgeos.GEOSCoordSeq_getX(seq, 1, byref(x2))
+    lgeos.GEOSCoordSeq_getY(seq, 1, byref(y2))
+    p1 = Point(x1.value, y1.value)
+    p2 = Point(x2.value, y2.value)
+    return (p1, p2)
+
+def snap(g1, g2, tolerance):
+    """Snap one geometry to another with a given tolerance
+
+    Vertices of the first geometry are snapped to vertices of the second
+    geometry. The resulting snapped geometry is returned. The input geometries
+    are not modified.
+
+    Parameters
+    ----------
+    g1 : geometry
+        The first geometry
+    g2 : geometry
+        The second geometry
+    tolerence : float
+        The snapping tolerance
+
+    Example
+    -------
+    >>> square = Polygon([(1,1), (2, 1), (2, 2), (1, 2), (1, 1)])
+    >>> line = LineString([(0,0), (0.8, 0.8), (1.8, 0.95), (2.6, 0.5)])
+    >>> result = snap(line, square, 0.5)
+    >>> result.wkt
+    'LINESTRING (0 0, 1 1, 2 1, 2.6 0.5)'
+    """
+    return(geom_factory(lgeos.methods['snap'](g1._geom, g2._geom, tolerance)))
